==> massxpert2_8.3.0.orig.tar.gz: massxpert2-8.3.0/src/gui/CleaveOligomerTableView.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#pragma once


/////////////////////// Qt includes
#include <QTableView>


/////////////////////// Local includes
#include "../nongui/OligomerList.hpp"


namespace msxps
{

namespace massxpert
{


  class CleavageDlg;


  class CleaveOligomerTableView : public QTableView
  {
    Q_OBJECT

    private:
    CleavageDlg *mp_parentDlg;

    OligomerList *mp_oligomerList;

    // For drag operations.
    QPoint m_dragStartPos;

    // We do not want to hide the parent class function here.
    using QAbstractItemView::startDrag;
    void startDrag();

    ///////// Contextual menu for copying to clipboard of mono/avg
    ///////// masses.
    QMenu *contextMenu;
    QAction *copyMonoAct;
    QAction *copyAvgAct;
    /////////

    protected:
    void currentChanged(const QModelIndex &, const QModelIndex &);
    void copyMassList(int);

    public:
    CleaveOligomerTableView(QWidget *parent = 0);
    ~CleaveOligomerTableView();

    void setOligomerList(OligomerList *);
    const OligomerList *oligomerList();

    CleavageDlg *parentDlg();
    void setParentDlg(CleavageDlg *);

    int selectedOligomers(OligomerList *, int = 0) const;

    QString *selectedOligomersAsPlainText(
      const QString &pattern = QString(),
      QString                = "$",
      bool                   = false,
      bool                   = false,
      libmass::MassType      = libmass::MassType::MASS_MONO) const;
    QString *selectedOligomersAsPlainTextWithDelimiter(libmass::Oligomer *p_oligomer,
                                                       const QString &delimiter,
                                                       bool withSequence,
                                                       bool forXpertMiner,
                                                       libmass::MassType massType) const;
    QString *
    selectedOligomersAsPlainTextWithPattern(libmass::Oligomer *p_oligomer,
                                            const QString &pattern) const;


    void mousePressEvent(QMouseEvent *);
    void mouseMoveEvent(QMouseEvent *);

    public slots:
    void itemActivated(const QModelIndex &);
    void copyMono();
    void copyAvg();
  };

} // namespace massxpert

} // namespace msxps

==> massxpert2_8.5.0.orig.tar.gz: massxpert2-8.5.0/src/gui/CleaveOligomerTableView.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#pragma once


/////////////////////// Qt includes
#include <QTableView>


/////////////////////// Local includes
#include "../nongui/OligomerList.hpp"


namespace MsXpS
{

namespace massxpert
{


  class CleavageDlg;


  class CleaveOligomerTableView : public QTableView
  {
    Q_OBJECT

    private:
    CleavageDlg *mp_parentDlg;

    OligomerList *mp_oligomerList;

    // For drag operations.
    QPoint m_dragStartPos;

    // We do not want to hide the parent class function here.
    using QAbstractItemView::startDrag;
    void startDrag();

    ///////// Contextual menu for copying to clipboard of mono/avg
    ///////// masses.
    QMenu *contextMenu;
    QAction *copyMonoAct;
    QAction *copyAvgAct;
    /////////

    protected:
    void currentChanged(const QModelIndex &, const QModelIndex &);
    void copyMassList(int);

    public:
    CleaveOligomerTableView(QWidget *parent = 0);
    ~CleaveOligomerTableView();

    void setOligomerList(OligomerList *);
    const OligomerList *oligomerList();

    CleavageDlg *parentDlg();
    void setParentDlg(CleavageDlg *);

    int selectedOligomers(OligomerList *, int = 0) const;

    QString *selectedOligomersAsPlainText(
      const QString &pattern = QString(),
      QString                = "$",
      bool                   = false,
      bool                   = false,
      libXpertMass::MassType      = libXpertMass::MassType::MASS_MONO) const;
    QString *selectedOligomersAsPlainTextWithDelimiter(libXpertMass::Oligomer *p_oligomer,
                                                       const QString &delimiter,
                                                       bool withSequence,
                                                       bool forXpertMiner,
                                                       libXpertMass::MassType massType) const;
    QString *
    selectedOligomersAsPlainTextWithPattern(libXpertMass::Oligomer *p_oligomer,
                                            const QString &pattern) const;


    void mousePressEvent(QMouseEvent *);
    void mouseMoveEvent(QMouseEvent *);

    public slots:
    void itemActivated(const QModelIndex &);
    void copyMono();
    void copyAvg();
  };

} // namespace massxpert

} // namespace MsXpS
